sqlobject.tests.test_select module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_select module

class `sqlobject.tests.test_select.` `Counter2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = counter2
  property `n1`
  property `n2`
  `q` = counter2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_select.Counter2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'counter2'

class `sqlobject.tests.test_select.` `IterTest`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = iter_test
  property `name`
  `q` = iter_test
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_select.IterTest`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'iter_test'

class `sqlobject.tests.test_select.` `TestSelect`

  Bases: `object`

  `accumulateEqual`(func, counters, value)
  `counterEqual`(counters, value)
  `setup_method`(meth)
  `test_1`()
  `test_2`()

class `sqlobject.tests.test_select.` `UniqTest`(**kw)

  Bases: `sqlobject.main.SQLObject`

  classmethod `byName`(val, connection=None)
  `j` = uniq_test
  property `name`
  `q` = uniq_test
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_select.UniqTest`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'uniq_test'

`sqlobject.tests.test_select.` `setupIter`()

`sqlobject.tests.test_select.` `test_00_normal`()

`sqlobject.tests.test_select.` `test_00b_lazy`()

`sqlobject.tests.test_select.` `test_01_turn_to_list`()

`sqlobject.tests.test_select.` `test_02_generator`()

`sqlobject.tests.test_select.` `test_03_ranged_indexed`()

`sqlobject.tests.test_select.` `test_04_indexed_ended_by_exception`()

`sqlobject.tests.test_select.` `test_05_select_limit`()

`sqlobject.tests.test_select.` `test_06_contains`()

`sqlobject.tests.test_select.` `test_07_contains_special`()

`sqlobject.tests.test_select.` `test_by_uniq`()

`sqlobject.tests.test_select.` `test_selectBy`()

`sqlobject.tests.test_select.` `test_selectBy_kwargs`()

`sqlobject.tests.test_select.` `test_select_LIKE`()

`sqlobject.tests.test_select.` `test_select_RLIKE`()

`sqlobject.tests.test_select.` `test_select_getOne`()

`sqlobject.tests.test_select.` `test_select_perConnection`()

`sqlobject.tests.test_select.` `test_select_sqlbuilder`()